; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional)
;   buffer.time = time (optional)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas. Each of these
;   buttons or directions is referred to as a "symbol".
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   greater-than (>) - means there must be no other keys pressed or released
;                      between the previous and the current symbol.
;          egs. command = a, >~a   ;press a and release it without having hit
;                                  ;or released any other keys in between
;   You can combine the symbols:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;
;   Note: Successive direction symbols are always expanded in a manner similar
;         to this example:
;           command = F, F
;         is expanded when MUGEN reads it, to become equivalent to:
;           command = F, >~F, >F
;
;   It is recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This makes the command easier
;   to do.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. The default
;   value for this is set in the [Defaults] section below. A typical
;   value is 15.
;
; - buffer.time (optional)
;   Time that the command will be buffered for. If the command is done
;   successfully, then it will be valid for this time. The simplest
;   case is to set this to 1. That means that the command is valid
;   only in the same tick it is performed. With a higher value, such
;   as 3 or 4, you can get a "looser" feel to the command. The result
;   is that combos can become easier to do because you can perform
;   the command early. Attacks just as you regain control (eg. from
;   getting up) also become easier to do. The side effect of this is
;   that the command is continuously asserted, so it will seem as if
;   you had performed the move rapidly in succession during the valid
;   time. To understand this, try setting buffer.time to 30 and hit
;   a fast attack, such as KFM's light punch.
;   The default value for this is set in the [Defaults] section below. 
;   This parameter does not affect hold-only commands (eg. /F). It
;   will be assumed to be 1 for those commands.
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10


;-| Button Remapping |-----------------------------------------------------
; This section lets you remap the player's buttons (to easily change the
; button configuration). The format is:
;   old_button = new_button
; If new_button is left blank, the button cannot be pressed.
[Remap]
x = x
y = y
z = z
a = a
b = b
c = c
s = s
;  Note that if you modify the button remapping scheme here, this character will
; still be able to correctly detect the basic commands of other characters
; complying with the basic command order specified below, as long as their
; buttons haven't been remapped.  But no character (not even one with the same
; remapping scheme, not even another instance of this character) will be able to
; correctly detect this character's commands.  This shouldn't ever result in any
; false positives, but it could delay correct positives, and could erroneously
; make the helper AI activation method trigger a false negative in team simul
; modes, in which case the XOR-ed commands method would be needed to provide
; backup.  But of course, this isn't an issue in any version of Mugen prior to
; version 2002.04.14.

;-| Default Values |-------------------------------------------------------
[Defaults]
; Default value for the "time" parameter of a Command. Minimum 1.
command.time = 15

; Default value for the "buffer.time" parameter of a Command. Minimum 1,
; maximum 30.
command.buffer.time = 1


; These 11 Single Button and Hold Dir commands must be placed here at the top
; of the CMD, above all other commands, and in the standard order shown here,
; in order for the "Compatibly Partnered" version (9742) of the helper AI
; activation method to work with different partners in simul team mode.
; (When the partner is not compatible, then it's best to just use the regular
; version (9741) and rely on the XOR method for backup in case a human
; partner's input turns off the CPU partner's AI.)
;   (Now, even if you do not intend to give your character any custom AI, it
; would still be nice if you would place the commands at the top of your CMD,
; for the sake of other characters which do use this AI activation method.
; And then, define Anim 9741 in your AIR file to indicate to other characters
; that your character is compatible.
;   It may slightly increase the chances of faulty AI activation if the user
; is using characters with a poor implementation of the old humanly-impossible
; commands AI activation method when fighting against your character, but
; other than that, there's really no particular reason not to.  And you can
; change the names of the commands if you want.  For compatibility, all that
; really matters is the "command" and "time" parameters.)
;
; Please don't add any extra definitions for any of these 11 basic command
; names, nor for any of the 7 "hold[button]" command names that follow.
; For example, things like this should be avoided:
;	[Command]
;	name = "z"
;	command = y+b
;	time = 1
; There are several workarounds possible to achieve the same effect.  Please
; feel free to ask me about it if you have any uncertainty.
; Violating this rule would cause the KeyCtrl Helper method and/or the XORed
; Commands method to malfunction, and could also interfere with other future
; applications of this command order standard.
;
;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

;-| Hold Button |----------------------------------------------------------
; Please define Anim 74140108 in your AIR file if AND ONLY IF you place these
; 7 Hold Button commands immediately after the 11 Single Button and Hold Dir
; commands at the very top of your CMD list, as demonstrated here.
; In this version of the AI code, these commands are only used by the XOR
; method, and thus are optional.  But there remains a possibility that a
; future version of the helper method might be helped by having these
; commands placed here, and Anim 74140108 would then be used to indicate
; that a partner character has a compatible CMD.

[Command]
name = "holda"
command = /a
time = 1

[Command]
name = "holdb"
command = /b
time = 1

[Command]
name = "holdc"
command = /c
time = 1

[Command]
name = "holdx"
command = /x
time = 1

[Command]
name = "holdy"
command = /y
time = 1

[Command]
name = "holdz"
command = /z
time = 1

[Command]
name = "holdstart"
command = /s
time = 1

;--- None of your own command definitions should be above this line. ---

;-| CPU |--------------------------------------------------------------
; Note that if you make any changes to the basic one-button or recovery
; commands, you'll need to make the same changes to their matching commands here
; and/or in the XOR VarSet controller.  That includes things like, for example:
;  * changing the recovery command to use a different combination of buttons.
;  * renaming the b button command as "d", or the start button command as "s".
;  * switching the button names around, e.g. so button y triggers "a" and button a triggers "y".
;  * having more than one way to trigger the same command name.
; If you understand how the XOR method works, the proper changes should be obvious.
; If you don't understand it, then simply disable the lines in the XOR VarSet
; controller that correspond to the commands you've altered.

[Command]
name = "a2"
command = a
time = 1

[Command]
name = "b2"
command = b
time = 1

[Command]
name = "c2"
command = c
time = 1

[Command]
name = "x2"
command = x
time = 1

[Command]
name = "y2"
command = y
time = 1

[Command]
name = "z2"
command = z
time = 1

[Command]
name = "start2"
command = s
time = 1

[Command]
name = "holdfwd2"
command = /$F
time = 1

[Command]
name = "holdback2"
command = /$B
time = 1

[Command]
name = "holdup2"
command = /$U
time = 1

[Command]
name = "holddown2"
command = /$D
time = 1

[Command]
name = "holda2"
command = /a
time = 1

[Command]
name = "holdb2"
command = /b
time = 1

[Command]
name = "holdc2"
command = /c
time = 1

[Command]
name = "holdx2"
command = /x
time = 1

[Command]
name = "holdy2"
command = /y
time = 1

[Command]
name = "holdz2"
command = /z
time = 1

[Command]
name = "holdstart2"
command = /s
time = 1

[Command]
name = "recovery2"
command = x+y
time = 1

; Here add matching commands for any moves that must never be used randomly
; by the computer, such as suicide moves and super moves, and add the pairs
; to the XOR VarSet controller in State -3.

; If you're desperate to make sure that the AI always gets turned on as soon
; as possible, you can add more equivalents for your own commands here too,
; and add to the XOR VarSet controller's triggers accordingly.

; And of course, if you've run out of unique command labels (Mugen allows
; 128), you can remove as many of these as you want.  You'll of course need
; to modify the XOR VarSet controller's triggers accordingly, but Mugen
; will let you know if you forget to do so. :)


;-| Super Motions |--------------------------------------------------------
;The following two have the same name, but different motion.
;Either one will be detected by a "command = TripleKFPalm" trigger.
;Time is set to 20 (instead of default of 15) to make the move
;easier to do.
;
[Command]
name = "BackStab"
command = ~F, D, B, x+y
[Command]
name = "BackStab"
command = ~F, DF, D, DB, B, x+y
[Command]
name = "BackStab_wd"
command = ~B, D, F, x+y
[Command]
name = "BackStab_wd"
command = ~B, DB, D, DF, F, x+y
[Command]
name = "BackStab"
command = ~F, D, B, z
[Command]
name = "BackStab"
command = ~F, DF, D, DB, B, z
[Command]
name = "BackStab_wd"
command = ~B, D, F, z
[Command]
name = "BackStab_wd"
command = ~B, DB, D, DF, F, z

[Command]
name = "GenericSuper"
command = ~D, DF, F, D, DF, F, x
time = 20
[Command]
name = "GenericSuper"
command = ~D, DF, F, D, DF, F, y
time = 20
[Command]
name = "GenericSuper"
command = ~D, F, D, F, x
time = 20
[Command]
name = "GenericSuper"
command = ~D, F, D, F, y
time = 20
[Command]
name = "GenericSuper"
command = ~D, DF, F, D, DF, F, z
time = 20
[Command]
name = "GenericSuper"
command = ~D, F, D, F, z
time = 20

[Command]
name = "SaberSuper"
command = ~D, DB, B, D, DB, B, x
time = 20
[Command]
name = "SaberSuper"
command = ~D, DB, B, D, DB, B, y
time = 20
[Command]
name = "SaberSuper"
command = ~D, B, D, B, x
time = 20
[Command]
name = "SaberSuper"
command = ~D, B, D, B, y
time = 20
[Command]
name = "SaberSuper"
command = ~D, DB, B, D, DB, B, z
time = 20
[Command]
name = "SaberSuper"
command = ~D, B, D, B, z
time = 20

[Command]
name = "DeadRinger"
command = ~D, DB, B, D, DB, B, a
time = 20
[Command]
name = "DeadRinger"
command = ~D, DB, B, D, DB, B, b
time = 20
[Command]
name = "DeadRinger"
command = ~D, B, D, B, a
time = 20
[Command]
name = "DeadRinger"
command = ~D, B, D, B, b
time = 20

[Command]
name = "Houtenjin"
command = ~D, DF, F, D, DF, F, a
time = 20
[Command]
name = "Houtenjin"
command = ~D, DF, F, D, DF, F, b
time = 20
[Command]
name = "Houtenjin"
command = ~D, F, D, F, a
time = 20
[Command]
name = "Houtenjin"
command = ~D, F, D, F, b
time = 20
;[Command]
;name = "Houtenjin"
;command = ~D, DF, F, D, DF, F, z
;time = 20
;[Command]
;name = "Houtenjin"
;command = ~D, F, D, F, z
;time = 20

[Command]
name = "SmashKFUpper"
command = ~D, DB, B, D, DB, B, x;~F, D, DF, F, D, DF, x
time = 20

[Command]
name = "SmashKFUpper"   ;Same name as above
command = ~D, DB, B, D, DB, B, y;~F, D, DF, F, D, DF, y
time = 20

;-| Special Motions |------------------------------------------------------
[Command]
name = "Matador"
command = ~D, DF, F, a
[Command]
name = "Matador"
command = ~D, F, a
[Command]
name = "Matador"
command = ~D, DF, F, b
[Command]
name = "Matador"
command = ~D, F, b
[Command]
name = "Matador"
command = ~D, DF, F, ~a
[Command]
name = "Matador"
command = ~D, F, ~a
[Command]
name = "Matador"
command = ~D, DF, F, ~b
[Command]
name = "Matador"
command = ~D, F, ~b

[Command]
name = "MatadorEX"
command = ~D, DF, F, a+b
[Command]
name = "MatadorEX"
command = ~D, F, a+b
[Command]
name = "MatadorEX"
command = ~D, DF, F, c
[Command]
name = "MatadorEX"
command = ~D, F, c

[Command]
name = "r_Matador"
command = ~D, DB, B, a
[Command]
name = "r_Matador"
command = ~D, B, a
[Command]
name = "r_Matador"
command = ~D, DB, B, b
[Command]
name = "r_Matador"
command = ~D, B, b
[Command]
name = "r_Matador"
command = ~D, DB, B, ~a
[Command]
name = "r_Matador"
command = ~D, B, ~a
[Command]
name = "r_Matador"
command = ~D, DB, B, ~b
[Command]
name = "r_Matador"
command = ~D, B, ~b

[Command]
name = "r_MatadorEX"
command = ~D, DB, B, a+b
[Command]
name = "r_MatadorEX"
command = ~D, B, a+b
[Command]
name = "r_MatadorEX"
command = ~D, DB, B, c
[Command]
name = "r_MatadorEX"
command = ~D, B, c

[Command]
name = "Sucker1"
command = ~D, B, x
[Command]
name = "Sucker2"
command = ~D, B, y
[Command]
name = "Sucker1"
command = ~D, DB, B, x
[Command]
name = "Sucker2"
command = ~D, DB, B, y
[Command]
name = "Sucker1"
command = ~D, B, ~x
[Command]
name = "Sucker2"
command = ~D, B, ~y
[Command]
name = "Sucker1"
command = ~D, DB, B, ~x
[Command]
name = "Sucker2"
command = ~D, DB, B, ~y
[Command]
name = "SuckerEX"
command = ~D, B, x+y
[Command]
name = "SuckerEX"
command = ~D, DB, B, x+y
[Command]
name = "SuckerEX"
command = ~D, B, z
[Command]
name = "SuckerEX"
command = ~D, DB, B, z

[Command]
name = "PlasmaKick1"
command = ~F, D, B, a
[Command]
name = "PlasmaKick2"
command = ~F, D, B, b
[Command]
name = "PlasmaKick1"
command = ~F, DF, D, DB, B, a
[Command]
name = "PlasmaKick2"
command = ~F, DF, D, DB, B, b
[Command]
name = "PlasmaKick1"
command = ~F, D, B, ~a
[Command]
name = "PlasmaKick2"
command = ~F, D, B, ~b
[Command]
name = "PlasmaKick1"
command = ~F, DF, D, DB, B, ~a
[Command]
name = "PlasmaKick2"
command = ~F, DF, D, DB, B, ~b
[Command]
name = "PlasmaKickEX"
command = ~F, D, B, a+b
[Command]
name = "PlasmaKickEX"
command = ~F, DF, D, DB, B, a+b
[Command]
name = "PlasmaKickEX"
command = ~F, D, B, c
[Command]
name = "PlasmaKickEX"
command = ~F, DF, D, DB, B, c

[Command]
name = "r_PlasmaKick1"
command = ~B, D, F, a
[Command]
name = "r_PlasmaKick2"
command = ~B, D, F, b
[Command]
name = "r_PlasmaKick1"
command = ~B, DB, D, DF, F, a
[Command]
name = "r_PlasmaKick2"
command = ~B, DB, D, DF, F, b
[Command]
name = "r_PlasmaKick1"
command = ~B, D, F, ~a
[Command]
name = "r_PlasmaKick2"
command = ~B, D, F, ~a
[Command]
name = "r_PlasmaKick1"
command = ~B, DB, D, DF, F, ~a
[Command]
name = "r_PlasmaKick2"
command = ~B, DB, D, DF, F, ~b
[Command]
name = "r_PlasmaKickEX"
command = ~B, D, F, a+b
[Command]
name = "r_PlasmaKickEX"
command = ~B, DB, D, DF, F, b+b
[Command]
name = "r_PlasmaKickEX"
command = ~B, D, F, c
[Command]
name = "r_PlasmaKickEX"
command = ~B, DB, D, DF, F, c

[Command]
name = "GonnaRapeYou1"
command = ~D, DF, F, x
[Command]
name = "GonnaRapeYou2"
command = ~D, F, y
[Command]
name = "GonnaRapeYou1"
command = ~D, DF, F, x
[Command]
name = "GonnaRapeYou2"
command = ~D, F, y
[Command]
name = "GonnaRapeYou1"
command = ~D, DF, F, ~x
[Command]
name = "GonnaRapeYou2"
command = ~D, F, ~y
[Command]
name = "GonnaRapeYou1"
command = ~D, DF, F, ~x
[Command]
name = "GonnaRapeYou2"
command = ~D, F, ~y
[Command]
name = "GonnaRapeYouEX"
command = ~D, DF, F, x+y
[Command]
name = "GonnaRapeYouEX"
command = ~D, F, x+y
[Command]
name = "GonnaRapeYouEX"
command = ~D, DF, F, z
[Command]
name = "GonnaRapeYouEX"
command = ~D, F, z

[Command]
name = "FF_ab"
command = F, F, a+b

[Command]
name = "FF_a"
command = F, F, a

[Command]
name = "FF_b"
command = F, F, b

[Command]
name = "PutDown"
command = D, D
time = 10

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

[Command]
name = "SupahJump"
;command = ~$D, $U
command = ~$D, $U
time = 5
buffer.time = 2

[Command]
name = "ChargedSupahJump"
;command = ~$D, $U
command = ~12$D, $U
time = 5
buffer.time = 2


;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = x+y
time = 1

[Command]
name = "TwoPunches"
command = x+y
time = 1

[Command]
name = "TwoKicks"
command = a+b
time = 1

[Command]
name = "GuardAttack"
command = y+b
time = 1

[Command]
name = "Dodge"
command = x+a
time = 1

[Command]
name = "GuardAttack"
command = z
time = 1

[Command]
name = "Dodge"
command = c
time = 1

[Command]
name = "TwoPunches"
command = z
time = 1

[Command]
name = "TwoKicks"
command = c
time = 1

[Command]
name = "upper_what"
command = ~15$D, $U, x
time = 10
[Command]
name = "upper_what"
command = ~15$D, $U, y
time = 10
[Command]
name = "upper_what"
command = ~15$D, $U, z
time = 10
[Command]
name = "upper_what"
command = ~15$D, $U, a
time = 10
[Command]
name = "upper_what"
command = ~15$D, $U, b
time = 10
[Command]
name = "upper_what"
command = ~15$D, $U, c
time = 10



;-| Dir + Button |---------------------------------------------------------
[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

; The main purpose of having these next two controllers here at the top of
; StateDef -1 is to make sure the AI helper never changes to a different state,
; nor encounters any VarSets within State -1.
; But they also improve efficiency by preventing Mugen from wasting time
; processing the entire State -1 for the helper.
[State -1, AI Helper Check]
type = ChangeState
trigger1 = IsHelper(9741)
value = 9741

[State -1, AI Helper Check 2]
type = ChangeState
trigger1 = IsHelper(9742)
value = 9742

; This is generally the best place to put most of your AI directives.  For
; example, this controller would only be executed when the CPU is in control:
;
; [State -1, Haha!]
; type = ChangeState
; trigger1 = var(0) ; (Or use "var(58)>0" if you've chosen not to
;                   ; use the Simplifier variable/controller.)
; trigger1 = ctrl
; trigger1 = StateType = S
; trigger1 = MoveType = I
; trigger1 = P2MoveType = H
; trigger1 = NumEnemy = 1
; trigger1 = Enemy,GetHitVar(HitTime) > 60
; trigger1 = PrevStateNo != 195
; trigger1 = Random < 99
; value = 195

; And of course, most human-only command-based ChangeStates also belong
; in State -1.  For example, this move would only be performable by a human:
;
; [State -1, Death Before Dishonor]
; type = ChangeState
; trigger1 = command = "suicide"
; trigger1 = !var(0) ; (Or use "var(58)<1" if you've chosen not to
;                    ; use the Simplifier variable/controller.)
; trigger1 = ctrl
; trigger1 = StateType != A
; trigger1 = MoveType = I
; value = {suicide state number}


;===========================================================================
;---------------------------------------------------------------------------


;===========================================================================
;This is not a move, but it sets up var(1) to be 1 if conditions are right
;for a combo into a special move (used below).
;Since a lot of special moves rely on the same conditions, this reduces
;redundant logic.
[State -1, Combo condition Reset]
type = VarSet
trigger1 = 1
var(9) = 0

[State -1, Combo condition Check]
type = VarSet
trigger1 = statetype != A
trigger1 = (ctrl) || (stateno = 100)
trigger2 = (stateno = [200,299]) || (stateno = [400,499])
trigger2 = stateno != 440 ;Except for sweep kick
trigger2 = anim != 230
trigger2 = anim != 240
trigger2 = anim != 250
trigger2 = anim != 210
trigger2 = anim != 219
trigger2 = anim != 207
trigger2 = anim != 220
trigger2 = stateno != 410
trigger2 = movecontact
trigger3 = (stateno = 1156 || stateno = 1159) && (animelemtime(9) >= 0)
var(9) = 1

[State -1, AI Tactic Cycle]
type = VarSet
triggerall = var(55)
trigger1 = stateno != [120,169]
trigger1 = movetype = H
trigger1 = time = 1
trigger2 = p2stateno = 5110
trigger2 = random < 500
trigger3 = p2stateno = 1001
var(54) = random%3

[State -1, AI Defense To Aggresion]
type = VarSet
triggerall = var(55)
triggerall = var(54) = 2
trigger1 = random < 80
trigger1 = p2movetype = H
trigger1 = p2stateno != [120,169]
trigger2 = stateno = 1001
trigger2 = time = 1
trigger2 = random < 500
var(54) = random%2
ignorehitpause = 1

[State -1, AI Prepare To Just Block]
type = VarSet
triggerall = var(55)
triggerall = var(54) != 2
trigger1 = random < 200
trigger1 = p2movetype = A
trigger1 = stateno = 5120
trigger2 = p2stateno = 5120
trigger2 = random < 80
trigger3 = random < 100
trigger3 = stateno = 1000 || stateno = 1020
trigger3 = animtime = 0
trigger4 = moveguarded = 1
trigger4 = random < 100
var(54) = 2
ignorehitpause = 1

[State -1, AI Vurneability encourages Aggresion]
type = VarSet
triggerall = var(55)
triggerall = var(54) != 1
triggerall = random < 100
trigger1 = enemynear, ctrl = 0
trigger1 = p2movetype = I
trigger1 = p2statetype != L
trigger1 = p2statetype != A
trigger1 = p2stateno != [5100,5200]
var(54) = 1
ignorehitpause = 1

;===========================================================================
;---------------------------------------------------------------------------
; AI BEGIN

[State -1, AI Consideration reset]
type = VarSet
trigger1 = stateno != 40
var(52) = 0
ignorehitpause = 1

[State AI, Consider backing off]
type = VarSet
triggerall = var(55)
triggerall = var(52) = 0 || random < 80
triggerall = random < 200
triggerall = numenemy
triggerall = (p2stateno = [5110,5130]) || ((enemynear,time <= 10) && (enemynear,prevstateno = 5120))
triggerall = p2bodydist x <= 33
triggerall = backedgedist >= 33
triggerall = time >= 6-var(55) || random < 10
trigger1 = stateno != 40
trigger1 = ctrl
var(52) = ifelse(random<750,105,40)

[State AI, Consider S.X]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+var(55)
triggerall = var(55)
triggerall = random < (66*var(55)); + (150*(movehit))
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 150) || (EnemyNear, animtime >= -6)
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-5,0),ifelse(stateno=200,40,50)-(6*(movecontact>=1))]
triggerall = p2dist y >= -90 - (enemynear,vel y*5)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -70
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = ctrl || stateno = 100
trigger2 = (stateno = [200,201]) || stateno = 400 || stateno = 430 || stateno = 211
trigger2 = movecontact
var(52) = 200
ignorehitpause = 1
[State AI, Consider S.Y]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+var(55)+(200*(stateno=[200,211]))
triggerall = var(55)
triggerall = random < (64*var(55)) + (333*(movehit)) + (100*(stateno=[200,211]))
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 100) || (EnemyNear, animtime >= -13)
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-5,ifelse(stateno=200,15,0)),ifelse(stateno=202||stateno=210,55,ifelse(stateno=200,65,79))-(6*(movecontact>=1))]
triggerall = p2dist y >= ifelse((p2bodydist x>35),-90,-47) - (enemynear,vel y*6)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= ifelse((p2bodydist x>35),-60,-50)
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = ctrl || stateno = 100
trigger2 = (stateno = [201,202]) || stateno = 400 || stateno = 430 || stateno = 211 || (stateno = 210 && anim = 215)
trigger2 = movecontact
trigger3 = (stateno = 1156 || stateno = 1159) && (animelemtime(9) >= 0)
var(52) = 210
ignorehitpause = 1
[State AI, Consider S.A]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+var(55)
triggerall = var(55)
triggerall = random < (62*var(55)) + (222*(movehit))
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 125) || (EnemyNear, animtime >= -9)
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-5,0),125-(6*(movecontact>=1))]
triggerall = (p2bodydist x != [13,20]) || (!movecontact)
triggerall = p2dist y >= ifelse((p2bodydist x>20),-70,-47) - (enemynear,vel y*8)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= ifelse((p2bodydist x>20),-50,-38)
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
triggerall = enemynear,anim != 5300 || p2bodydist x <= 20
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = ctrl
trigger2 = stateno = 200 || stateno = 202 || stateno = 400 || (stateno = 210 && anim = 215)
trigger2 = movecontact
trigger3 = (stateno = 1156 || stateno = 1159) && (animelemtime(9) >= 0)
var(52) = 230
ignorehitpause = 1
[State AI, Consider S.B]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+var(55)
triggerall = var(55)
triggerall = random < (60*var(55)) + (200*(movehit)) || (stateno = 52 && random < 80)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 150) || (EnemyNear, animtime >= -9)
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-5,0),117-(6*(movecontact>=1))]
triggerall = (p2bodydist x != [17,25]) || (!movecontact)
triggerall = p2dist y >= -100 - (enemynear,vel y*8)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= ifelse((p2bodydist x>25),-70,-60)
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
triggerall = enemynear,anim != 5300 || p2bodydist x <= 20
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = ctrl || stateno = 100
trigger2 = stateno = 200 || stateno = 201 || stateno = 202 || stateno = 400 || (stateno = 230 && anim = 235) || (stateno = 210 && anim = 215)
trigger2 = movecontact
trigger3 = (stateno = 1156 || stateno = 1159) && (animelemtime(9) >= 0)
var(52) = 240
ignorehitpause = 1

[State AI, Consider C.X]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+var(55)
triggerall = var(55)
triggerall = random < (64*var(55)) + (300*(movehit))
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 90) || (EnemyNear, animtime >= -5)
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-5,0),44-(6*(movecontact>=1))]
triggerall = p2dist y >= -40 - (enemynear,vel y*5)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -70
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = ctrl
trigger2 = (stateno = 1156 || stateno = 1159) && (animelemtime(9) >= 0)
var(52) = 400
ignorehitpause = 1
[State AI, Consider C.Y]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+var(55)
triggerall = var(55)
triggerall = random < (60*var(55)) + (222*(movehit)) || (stateno = 52 && random < 100)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 90) || (EnemyNear, animtime >= -10)
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-5,0),47-(6*(movecontact>=1))]
triggerall = p2dist y >= -90 - (enemynear,vel y*9)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -70
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = ctrl || stateno = 100
trigger2 = stateno = 400 || stateno = 430
trigger2 = movecontact
trigger3 = (stateno = 1156 || stateno = 1159) && (animelemtime(9) >= 0)
var(52) = 410
ignorehitpause = 1
[State AI, Consider C.A]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+var(55)
triggerall = var(55)
triggerall = random < (66*var(55)) + (300*(movehit))
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 168) || (EnemyNear, animtime >= -5)
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-5,0),60-(6*(movecontact>=1))]
triggerall = p2dist y >= -10 - (enemynear,vel y*4)
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = ctrl
trigger2 = stateno = 430
trigger2 = movecontact
trigger3 = (stateno = 1156 || stateno = 1159) && (animelemtime(9) >= 0)
var(52) = 430
ignorehitpause = 1
[State AI, Consider C.B]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+var(55)
triggerall = var(55)
triggerall = random < (62*var(55)) + (222*(movehit))
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 111) || (EnemyNear, animtime >= -9)
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-5,0),52-(6*(movecontact>=1))]
triggerall = p2dist y >= -10 - (enemynear,vel y*8)
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = ctrl
trigger2 = stateno = 200 || stateno = 400 || stateno = 430
trigger2 = movehit || (moveguarded && p2statetype != C)
trigger3 = (stateno = 1156 || stateno = 1159) && (animelemtime(9) >= 0)
var(52) = 440
ignorehitpause = 1

[State AI, Consider F.X]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+var(55)
triggerall = var(55)
triggerall = random < (60*var(55)) + (300*(movehit))
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 150) || (EnemyNear, animtime >= -6)
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [ifelse(p2statetype!=A,15,0),106-(6*(movecontact>=1))]
triggerall = p2dist y >= -80 - (enemynear,vel y*13)
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
triggerall = prevstateno != 52
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = ctrl || stateno = 100
trigger2 = (stateno = [200,202]) || (stateno = 210 && anim = 215) || (stateno = 230 && anim = 235) || (stateno = 240 && anim = 245) || stateno = 400 || stateno = 430 || stateno = 211 || stateno = 440
trigger2 = movehit || (moveguarded && p2statetype != S)
trigger3 = (stateno = 1156 || stateno = 1159) && (animelemtime(9) >= 0)
var(52) = 207
ignorehitpause = 1
[State AI, Consider F.A]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+var(55)
triggerall = var(55)
triggerall = random < (60*var(55)) + (300*(movehit))
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (EnemyNear, animtime >= -15)
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [ifelse(p2statetype!=A,20,25),121-(9*(movecontact>=1))]
triggerall = p2dist y >= -25 - (enemynear,vel y*15)
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = ctrl || stateno = 100
trigger2 = (stateno = [200,202]) || (stateno = 210 && anim = 215) || (stateno = 230 && anim = 235) || (stateno = 240 && anim = 245) || stateno = 400 || stateno = 430 || stateno = 211 || stateno = 440
trigger2 = movehit || (moveguarded && p2statetype != C)
trigger2 = !movehit || (stateno != [200,201])
trigger3 = (stateno = 1156 || stateno = 1159) && (animelemtime(9) >= 0)
var(52) = 237
ignorehitpause = 1

[State -1, J.A]
type = Varset
triggerall = numenemy
triggerall = var(52) = 0 || random < 123
triggerall = var(55)
triggerall = p2bodydist x = [-5+(vel x*3)+(enemynear,vel x*3),20+(vel x*3)+(enemynear,vel x*3)]
triggerall = P2dist y = [-51+(vel y*3)+(enemynear,vel y*3),46+(vel y*3)+(enemynear,vel y*3)]
triggerall = Statetype = A
triggerall = p2stateno != [5100,5120]
triggerall = p2Statetype = A || vel y >= 0
triggerall = (stateno != [120,169])
triggerall = random < (23*var(55)) + (300*(movehit))
triggerall = time >= 7-var(55) || random < 10
trigger1 = ctrl
var(52) = 630
[State -1, J.X]
type = Varset
triggerall = numenemy
triggerall = var(52) = 0 || random < 80
triggerall = var(55)
triggerall = (p2bodydist x = [-1+(vel x*6)+(enemynear,vel x*6),29+(vel x*6)+(enemynear,vel x*6)]) || (movehit)
triggerall = P2dist y = [-70+(vel y*6)+(enemynear,vel y*6),0+(vel y*6)+(enemynear,vel y*6)]
triggerall = Statetype = A
triggerall = p2stateno != [5100,5120]
triggerall = p2Statetype = A
triggerall = (stateno != [120,169])
triggerall = random < (23*var(55)) + (300*(movehit))
triggerall = time >= 7-var(55) || random < 10
trigger1 = ctrl
trigger2 = (stateno = 630)
trigger2 = movecontact
trigger2 = sysvar(3) >= 3
var(52) = 600
[State -1, J.B]
type = Varset
triggerall = numenemy
triggerall = var(52) = 0 || random < 80
triggerall = var(55)
triggerall = (p2bodydist x = [-6+(vel x*6)+(enemynear,vel x*6),58+(vel x*6)+(enemynear,vel x*6)]) || (movehit)
triggerall = P2dist y = [-76+(vel y*6)+(enemynear,vel y*6),91+(vel y*6)+(enemynear,vel y*6)]
triggerall = Statetype = A
triggerall = p2stateno != [5100,5120]
triggerall = p2Statetype = A || vel y >= 0
triggerall = (stateno != [120,169])
triggerall = random < (23*var(55)) + (300*(movehit))
triggerall = time >= 7-var(55) || random < 10
trigger1 = ctrl
trigger1 = stateno != 50 || time >= 10
trigger2 = (stateno = 600) || (stateno = 630)
trigger2 = movecontact
trigger2 = sysvar(3) >= 3
var(52) = 640
[State -1, J.UB]
type = Varset
triggerall = numenemy
triggerall = var(52) = 0 || random < 80
triggerall = var(55)
triggerall = (p2bodydist x = [-8+(vel x*6)+(enemynear,vel x*6),23+(vel x*6)+(enemynear,vel x*6)]) || (movehit)
triggerall = P2dist y = [-150+(vel y*6)+(enemynear,vel y*6),30+(vel y*6)+(enemynear,vel y*6)]
triggerall = Statetype = A
triggerall = p2stateno != [5100,5120]
triggerall = p2Statetype = A || vel y >= 0
triggerall = (stateno != [120,169])
triggerall = random < (23*var(55)) + (300*(movehit))
triggerall = time >= 7-var(55) || random < 10
trigger1 = ctrl
trigger1 = stateno != 50 || time >= 10
trigger2 = (stateno = 600) || (stateno = 630) || (stateno = 640)
trigger2 = movecontact
trigger2 = sysvar(3) >= 3
var(52) = 645
[State -1, J.Y]
type = Varset
triggerall = numenemy
triggerall = var(52) = 0 || random < 80
triggerall = var(55)
triggerall = (p2bodydist x = [-1+(vel x*6)+(enemynear,vel x*6),24+(vel x*6)+(enemynear,vel x*6)]) || (movehit)
triggerall = P2dist y = [-100+(vel y*6)+(enemynear,vel y*6),69+(vel y*6)+(enemynear,vel y*6)]
triggerall = Statetype = A
triggerall = p2stateno != [5100,5120]
triggerall = p2Statetype = A || vel y >= 0
triggerall = (stateno != [120,169])
triggerall = random < (23*var(55)) + (300*(movehit))
triggerall = time >= 7-var(55) || random < 10
trigger1 = ctrl
trigger1 = stateno != 50 || time >= 10
trigger2 = (stateno = 600) || (stateno = 630) || (stateno = 640) || (stateno = 645)
trigger2 = movecontact
trigger2 = sysvar(3) >= 3
var(52) = 610
[State -1, J.BB]
type = Varset
triggerall = numenemy
triggerall = var(52) = 0 || random < 80
triggerall = var(55)
triggerall = p2bodydist x < -10
triggerall = (p2bodydist x = [-56+(vel x*6),0+(vel x*6)])
triggerall = P2dist y = [-30+(vel y*6),74+(vel y*6)]
triggerall = Statetype = A
triggerall = p2stateno != [5100,5120]
triggerall = p2Statetype = A || vel y >= 0
triggerall = (stateno != [120,169])
triggerall = random < (23*var(55))
triggerall = time >= 7-var(55) || random < 10
trigger1 = ctrl
var(52) = 647

[State AI, Consider Grabbin']
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || ( (random < 80+var(55)  + ((8*var(55))*(var(52)=[230,240])) ) && (var(52)!=[200,201]) && (var(52)!=[210,211]) )
triggerall = var(55)
triggerall = random < (44*var(55)) + ((20*var(55))*(movehit))
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 111) || (EnemyNear, animtime >= -3)
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-5,15),ifelse(power>=500,130,90)-(6*(movecontact>=1))]
triggerall = (p2dist y >= -50 - (enemynear,vel y*11))
triggerall = statetype != A
triggerall = p2stateno != [120,169]
triggerall = time >= 7-var(55) || random < 10
triggerall = enemynear,anim != 5300
triggerall = ( enemynear, vel y <= 0 ) || ( (enemynear, vel y*12) + (enemynear, pos y) <= -12 ) || (p2stateno != [5030,5120])
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = var(9)
trigger1 = var(54) != 2 || movehit
trigger1 = !moveguarded
trigger1 = stateno != [1150,1199]
var(52) = ifelse(power>=500&&(p2bodydist x>=90),1170,1150+ifelse((random<500&&p2bodydist x>35)||p2bodydist x>80,10,0))
ignorehitpause = 1
[State AI, Consider HIYAH]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || ( (random < 80+var(55)) && (var(52)!=[200,201]) && (var(52)!=[210,211]) )
triggerall = var(55)
triggerall = random < (20*var(55)) + ((15*var(55))*(movehit)) + (100*(p2statetype=A)) + ((lifemax - life)/4) || (stateno = 52 && random < 650)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 200) || (EnemyNear, animtime >= -3)
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x >= 25 || p2statetype = A
triggerall = (p2bodydist x = [ifelse(p2statetype!=A||statetype!=A,-5,4),100-(6*(movecontact>=1))]) || (!numhelper(1105))
triggerall = (p2dist y = [-157,47])
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -10
triggerall = time >= 7-var(55) || random < 10
triggerall = enemynear,anim != 5300
triggerall = prevstateno != 1101
triggerall = ( enemynear, vel y <= 0 ) || ( (enemynear, vel y*7) + (enemynear, pos y) <= -7 ) || (p2stateno != [5030,5120])
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = var(9)
trigger1 = var(54) != 2 || statetype = A
trigger2 = (stateno = [600,647]) || (stateno = 207)
trigger2 = movecontact
var(52) = ifelse(power>=500&&(p2bodydist x>=100&&random<100),1120,1100+ifelse(random<500||p2bodydist x>67,10,0))
ignorehitpause = 1
[State AI, Consider Sucking]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || ( (random < 80+var(55)) && (var(52)!=[200,201]) && (var(52)!=[210,211]) )
triggerall = var(55)
triggerall = random < (32*var(55)) + ((20*var(55))*(movehit))
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (EnemyNear, animtime >= -15)
triggerall = p2stateno != [5080,5110]
triggerall = (p2dist y = [-80,0]) || (enemynear,vel y <= 1)
triggerall = p2bodydist x >= 25 || p2statetype = A
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -60
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
triggerall = enemynear,anim != 5300
triggerall = frontedgedist >= 50
triggerall = ( enemynear, vel y <= 0 ) || ( (enemynear, vel y*12) + (enemynear, pos y) <= -12 ) || (p2stateno != [5030,5120])
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = var(9)
trigger1 = var(54) != 2
trigger1 = stateno != 1156
trigger1 = !moveguarded
var(52) = ifelse(power>=500&&(p2bodydist y>=-50&&random<100),1070,1050+ifelse(random<500||(p2bodydist x>=77&&p2movetype=H),10,0))
ignorehitpause = 1
[State AI, Consider Countering]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || ( (random < 80+var(55)) && (var(52)!=[200,201]) && (var(52)!=[210,211]) )
triggerall = var(55)
triggerall = random < (5*var(55)) + ((20*var(55))*(moveguarded)) + ((25*var(55))*(p2movetype=A&&(enemynear,facing != facing)))
triggerall = p2stateno != [5080,5130]
triggerall = p2movetype != H
triggerall = p2bodydist x >= 15 || p2movetype = A
triggerall = statetype != A
triggerall = random < (4*var(55)) || ((p2movetype = A && enemynear,facing != facing) && random < (39*var(55)) + ((lifemax - life)/16))
triggerall = facing != enemynear,facing
triggerall = time >= 7-var(55) || random < 10
triggerall = enemynear,anim != 5300
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = A
trigger1 = var(9)
trigger1 = !movehit
var(52) = 1000+((random%3)*10)
ignorehitpause = 1


[State AI, Consider rushing kickass]
type = VarSet
triggerall = numenemy
triggerall = !numhelper(3105)
triggerall = var(52) = 0 || (random < 100+var(55) && (var(52)!=[200,640]))
triggerall = var(55)
triggerall = random < 300 + ((lifemax - life)/16)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0 && enemynear, animtime <= -10)
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x <= 15 + abs(p2bodydist y/2) + (enemynear,vel x)
triggerall = p2bodydist y + (enemynear,vel y*6) >= ifelse(power>=2000,-90,-60)
triggerall = statetype != A
triggerall = power >= 1000
triggerall =(p2movetype = H) || (enemynear, ctrl = 0) || (enemynear, statetype = A)
triggerall = p2stateno != [120,165]
triggerall = (prevstateno != [3000,3902]) || (stateno = [3000,3902])
triggerall = prevstateno != 1001
triggerall = ( enemynear, vel y <= 0 ) || ( (enemynear, vel y*16) + (enemynear, pos y) <= -16 ) || (p2stateno != [5030,5120])
triggerall = time >= 7-var(55) || random < 10
trigger1 = var(9)
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 250
trigger2 = (stateno = 1050) || (stateno = 1060) || (stateno = 1070 && anim = 1051) || (stateno = 210 && anim = 219) || (stateno = 220) || (stateno = 410) || (stateno = 230 && anim = 230) || (stateno = 240 && anim = 240)
trigger2 = movehit >= 150
trigger3 = stateno = 3100
trigger3 = animelemtime(10) >= 0
trigger4 = stateno = 1101
var(52) = ifelse((power>=2000)&&(p2bodydist x>=80||random<500||life<=200),3010,3000)+ ifelse(!numhelper(3105)&&(p2bodydist x>=80||random<100),100,0)
ignorehitpause = 1
[State AI, Consider friggin' ripping off Hazama]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || (random < 100+var(55) && (var(52)!=[200,640]))
triggerall = var(55)
triggerall = random < 300 + ((lifemax - life)/16) + ((30*var(55))*(p2movetype=A&&(enemynear,facing != facing)))
triggerall = p2stateno != 5120
triggerall = p2dist y + (enemynear,vel y*6) = [-90,0]
triggerall = statetype != A
triggerall = power >= 1000
triggerall = (p2movetype = H) || (enemynear, ctrl = 0) || (enemynear, statetype = A)
triggerall = p2stateno != [120,165]
triggerall = (p2stateno != [0,20]) || random < 100
triggerall = (prevstateno != [3000,3902]) || (stateno = [3000,3902])
triggerall = prevstateno != 1001
triggerall = abs(enemynear,vel x) <= 4.5
;triggerall = ( enemynear, vel y <= 0 ) || ( (enemynear, vel y*16) + (enemynear, pos y) <= -16 ) || (p2stateno != [5030,5120])
triggerall = time >= 7-var(55) || random < 10
trigger1 = var(9)
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 250
trigger2 = (stateno = 1050) || (stateno = 1060) || (stateno = 1070 && anim = 1051) || (stateno = 210 && anim = 219) || (stateno = 220) || (stateno = 410) || (stateno = 230 && anim = 230) || (stateno = 240 && anim = 240)
trigger2 = movecontact
trigger3 = stateno = 3100
trigger3 = animelemtime(10) >= 0
trigger4 = stateno = 1101
var(52) = 3400
ignorehitpause = 1
[State AI, Consider throwing the bone]
type = VarSet
triggerall = !numhelper(3105)
triggerall = numenemy
triggerall = var(52) = 0 || (random < 100+var(55) && (var(52) != [3000,3010]))
triggerall = var(55)
triggerall = random < 300 + ((lifemax - life)/16)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0 && enemynear, animtime <= -10)
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x <= 280 || power >= 2000
triggerall = p2dist y + (enemynear,vel y*6) = [-100,0]
triggerall = statetype != A
triggerall = power >= 1000
triggerall =(p2movetype = H) || (enemynear, ctrl = 0) || (enemynear, statetype = A) || (random < 50)
triggerall = (p2stateno != [120,165]) || (random < 50)
triggerall =(prevstateno != [3000,3902]) || (stateno = [3000,3902])
triggerall = prevstateno != 1001
triggerall = ( enemynear, vel y <= 0 ) || ( (enemynear, vel y*20) + (enemynear, pos y) <= -20 ) || (p2stateno != [5030,5120])
triggerall = time >= 7-var(55) || random < 10
trigger1 = var(9)
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 250
trigger2 = (stateno = 1050) || (stateno = 1060) || (stateno = 1070 && anim = 1051) || (stateno = 210 && anim = 219) || (stateno = 220) || (stateno = 410) || (stateno = 230 && anim = 230) || (stateno = 240 && anim = 240)
trigger2 = movehit
trigger3 = stateno = 3002
trigger3 = anim = 3004
trigger3 = animelemtime(18) >= 0
trigger4 = stateno = 1101
var(52) = ifelse(random<500&&power>=2000,3110,3100)
ignorehitpause = 1
[State AI, Consider becoming a spy]
type = VarSet
triggerall = !numhelper(3105)
triggerall = numenemy
triggerall = var(52) = 0 || random < 100
triggerall = var(55)
triggerall = random < 100 + ((lifemax - life)/16)
triggerall = statetype != A
triggerall = power >= 1000
triggerall = (prevstateno != [3000,3902]) || (stateno = [3000,3902])
triggerall = prevstateno != 1001
triggerall = time >= 7-var(55) || random < 10
triggerall = !numhelper(3200)
triggerall = var(23) = 0
trigger1 = var(9)
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 250
trigger2 = (stateno = 1050) || (stateno = 1060) || (stateno = 1070 && anim = 1051) || (stateno = 210 && anim = 219) || (stateno = 220) || (stateno = 410) || (stateno = 230 && anim = 230) || (stateno = 240 && anim = 240)
trigger2 = moveguarded || (movehit && random < 50)
trigger3 = stateno = 3002
trigger3 = anim = 3004
trigger3 = animelemtime(18) >= 0
trigger4 = stateno = 1101
var(52) = 3200
ignorehitpause = 1

[State AI, Consider Throwing]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 900
triggerall = var(55)
triggerall = random < (111*var(55))
triggerall = p2stateno != [5080,5130]
triggerall = abs(p2bodydist x) < 12
triggerall = statetype != A
triggerall = p2movetype != H
triggerall = p2statetype != A
triggerall = prevstateno != [800,860]
trigger1 = stateno != 40
trigger1 = ctrl
var(52) = ifelse(random<250||abs(p2bodydist x)>8,1150,ifelse(random<500,800,830))
ignorehitpause = 1
[State -1, Consider an Air Throw]
type = Varset
triggerall = var(55)
triggerall = statetype = A
triggerall = ctrl
triggerall = p2bodydist X < 10
triggerall = abs(p2bodydist y) < 35
triggerall = (p2statetype = A)
trigger1 = p2movetype != H || (random < 500) || p2movetype = A
var(52) = 860

[State AI, Consider jumping in]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+var(55)
triggerall = var(55)
triggerall = p2stateno != [5080,5130]
triggerall = abs(p2bodydist x) < 40 + (35*(command="holdfwd"))
triggerall = statetype != A
triggerall = p2statetype = A && p2movetype = H
triggerall = ifelse(p2dist x<-5,command != "holdfwd",command!="holdback")
triggerall = !(var(40) & floor(exp(7*ln(2)) + 0.5) ) || !(var(40) & floor(exp(8*ln(2)) + 0.5) ) || !(var(40) & floor(exp(9*ln(2)) + 0.5) )
triggerall = (enemynear, pos y <= -45)
triggerall = command="holdup"
trigger1 = ctrl || stateno = 100 || stateno = 40
trigger2 = (stateno = 240 && anim = 245) || (stateno = 213)
trigger2 = time > 12 || movecontact
trigger3 = (stateno = 1156)
trigger3 = animelemtime(9) >= 0
trigger4 = stateno = 100
trigger5 = stateno = 3400
trigger5 = movehit
var(52) = ifelse(p2bodydist x>=20,41,42)+ifelse(p2dist y <= -100,3,0)
ignorehitpause = 1

[State AI, Defensive Trait]
type = VarSet
triggerall = var(55)
triggerall = var(52) = 0 || random < 100+var(55)
triggerall = statetype != A
triggerall = p2stateno != [5100,5130]
triggerall = stateno != [10,12]
triggerall = stateno != 40
triggerall = stateno != 100
triggerall = prevstateno != 1000 || random < 100
triggerall = p2movetype != H
triggerall = ctrl
trigger1 = random < 100 + floor( (p2life - life) / 1.5)
trigger1 = var(54) = 2
trigger1 = p2bodydist x = [30,180]
trigger2 = p2bodydist x <= 80
trigger2 = random < 500 + floor( (p2life - life) / 2.8)
trigger2 = var(54) != 1
trigger2 = enemynear,ctrl = 0
trigger2 = enemynear,animtime >= -6
trigger2 = p2movetype != A
var(52) = ifelse(power>=500&&random<100,1020,ifelse(power>=1000&&numhelper(3200)=0&&var(23)=0&&random<100,3200,ifelse(random<250,710,1000)))

[State AI, Defensive Suprise]
type = Varset
triggerall = var(55)
triggerall = var(52) = 0 || random < 100+var(55)
triggerall = var(54) = 2
triggerall = statetype != A
triggerall = p2movetype = A && (enemynear,facing != facing)
triggerall = enemynear, moveguarded
triggerall = power >= 500
triggerall = random < 50
triggerall = p2bodydist x <= 60
triggerall = p2bodydist y >= -60
trigger1 = stateno = [150,153]
var(52) = ifelse(random<100,710,700)

; Misc
[State AI, I C UR MAKIN MISTAKE]
type = VarSet
triggerall = var(55)
triggerall = var(52) = 0 || random < 100+var(55)
triggerall = statetype != A
triggerall = ((enemynear, ctrl = 0) && p2movetype != A) || (p2movetype = A && (enemynear, facing = facing))
;triggerall = var(54) != 2
triggerall = p2stateno != [5100,5130]
triggerall = p2bodydist x >= 60
triggerall = random < 500
triggerall = (stateno != [10,12]) || random < 100
triggerall = stateno != 20 || random < 500 || var(54) = 1
triggerall = stateno != 22
triggerall = stateno != 40
triggerall = stateno != 100
trigger1 = ctrl
var(52) = ifelse( random<500&&command="holdfwd", ifelse(random<500,40,100) , ifelse( random < 200&&numhelper(1105)=0 , ifelse(random<500,1100,1110) , ifelse(random<100&&power>=500,1070,1060) ) )


[State AI, Consider Advancing]
type = VarSet
triggerall = var(55)
triggerall = var(52) = 0 || random < 80+var(55)
triggerall = random < (33*var(55))
triggerall = ((enemynear, ctrl = 0) && p2movetype != A) || (p2movetype = A && (enemynear, facing = facing))
triggerall = (p2stateno != [5080,5130]) || (p2bodydist x = [45,100])
triggerall = p2bodydist x >= 45
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
trigger1 = stateno != 40
trigger1 = var(1)
trigger1 = !moveguarded
var(52) = ifelse(random<444&&(p2stateno != [5080,5130]),1050,ifelse(random<200,40,100))

[State AI, Taunt]
type = VarSet
triggerall = var(55)
triggerall = var(52) = 0 || random < 80+var(55)
triggerall = p2bodydist x >= 80
triggerall = statetype != A
triggerall = prevstateno != 195
triggerall = stateno != 195
triggerall = var(54) != 1
triggerall = ctrl
trigger1 = random < ifelse(p2bodydist x<=45,500,80)
trigger1 = (p2stateno = [5100,5200]) || p2statetype = L
trigger2 = random < 350
trigger2 = prevstateno = [1050,1070]
var(52) = ifelse(((random<900||var(54)=2)&&p2bodydist x<=45)||life<=200,105,ifelse(power>=1000&&numhelper(3200)=0&&var(23)=0&&random<100,3200,195))

[State AI, RUNNIN COMBO]
type = VarSet
triggerall = var(55)
triggerall = var(52) = 0 || random < 100+var(55)
triggerall = statetype != A
;triggerall = (p2movetype != A || EnemyNear, Facing = Facing)
triggerall = p2stateno != [5100,5130]
;triggerall = p2bodydist x = [-5,125]
triggerall = p2bodydist y = [-165,-15]
trigger1 = prevstateno = 220 || prevstateno = 1154
trigger1 = p2movetype = H
trigger1 = ctrl
var(52) = ifelse(p2bodydist x <= 60&&random<500,210, ifelse(p2bodydist x <= 80&&random<500,ifelse(random<500&&prevstateno!=1154,1160,1110 ),1050 ) )

[State AI, COUNTER COMBO]
type = VarSet
triggerall = var(55)
triggerall = var(52) = 0 || random < 100+var(55)
triggerall = statetype != A
;triggerall = (p2movetype != A || EnemyNear, Facing = Facing)
;triggerall = p2bodydist x = [-5,125]
;triggerall = p2bodydist y = [-165,-15]
triggerall = random < 900
trigger1 = prevstateno = 1001
trigger1 = p2movetype = H
trigger1 = ctrl
var(52) = ifelse( power>=3000&&p2bodydist x<=14&&facing=(enemynear,facing), 3300 , ifelse(p2bodydist x <= 35,200,ifelse(p2bodydist x <= 77,210,1100 + 10*(var(54)!=2) )) )


[State AI, STAB]
type = VarSet
triggerall = var(55)
triggerall = statetype != A
triggerall = ctrl
triggerall = p2stateno != [5100,5200]
triggerall = enemynear, prevstateno != 5120
triggerall = facing = (enemynear,facing)
triggerall = power >= 3000
triggerall = random < 900
trigger1 = p2bodydist X <= 30
trigger1 = (p2statetype = S) || (p2statetype = C)
var(52) = 3300


[State AI, GRAB COMBO]
type = Varset
triggerall = var(55)
trigger1 = stateno = 1151
trigger1 = prevstateno != 1170 || time >= 60
trigger1 = animelem = 15
var(52) = ifelse( prevstateno = 1170&&var(22)=0&&p2bodydist x<=50&&random<500 , 1171 , ifelse(random<750,1163,ifelse(random<500,1154,ifelse(random<250,1156,1159))) )


[State AI, Guard S]
type = ChangeState
triggerall = stateno != 40
triggerall = !numhelper(3200)
triggerall = (var(55)) && (StateType != A) && (Ctrl) && (EnemyNear, Facing != Facing) && (var(50)<40)
triggerall = time >= 7-var(55) || random < 10
trigger1 = (P2StateType != C) && (((P2MoveType = A) && (inguarddist)) || (EnemyNear, NumProj > 0))
value = ifelse(random<123&&(stateno!=[130,169]),ifelse(random<500&&p2bodydist x>=60,710,1000),130)


[State AI, Guard L]
type = ChangeState
triggerall = stateno != 40
triggerall = !numhelper(3200)
triggerall = (var(55)) && (StateType != A) && (Ctrl) && (EnemyNear, Facing != Facing) && (var(50)<40)
triggerall = time >= 7-var(55) || random < 10
trigger1 = (P2StateType = C) && (((P2MoveType = A) && (inguarddist)) || (EnemyNear, NumProj > 0))
value = ifelse(random<123&&p2bodydist x>=60&&(stateno!=[130,169]),710,ifelse(random<16,40,131))




;===========================================================================
;---------------------------------------------------------------------------
; AI END



;---------------------------------------------------------------------------
;Triple Kung Fu Palm (uses one super bar) (and BTW, THX Vans)
[State -1, BACKSTAB]
type = ChangeState
value = 3300
triggerall = (ifelse( (anim=[5,6]), (command="BackStab_wd"), (command = "BackStab") ) && !var(55)) || var(52) = 3300
triggerall = power >= 3000
trigger1 = var(9)
trigger2 = (stateno = 1050) || (stateno = 1060) || (stateno = 1070 && anim = 1051) || (stateno = 210 && anim = 219) || (stateno = 220) || (stateno = 410) || (stateno = 230 && anim = 230) || (stateno = 240 && anim = 240)
trigger2 = movecontact
trigger3 = stateno = 3100
trigger3 = animelemtime(10) >= 0
trigger4 = stateno = 1101

;Triple Kung Fu Palm (uses one super bar)
[State -1, Super]
type = ChangeState
value = ifelse((command="TwoPunches"||var(52)=3010)&&power>=2000,3010,3000)
triggerall = (ifelse( (anim=[5,6]), (command="SaberSuper"), (command = "GenericSuper") ) && !var(55)) || var(52) = 3000
triggerall = power >= 1000
trigger1 = var(9)
trigger2 = (stateno = 1050) || (stateno = 1060) || (stateno = 1070 && anim = 1051) || (stateno = 210 && anim = 219) || (stateno = 220) || (stateno = 410) || (stateno = 230 && anim = 230) || (stateno = 240 && anim = 240)
trigger2 = movecontact
trigger3 = stateno = 3100
trigger3 = animelemtime(10) >= 0
trigger4 = stateno = 1101

;Triple Kung Fu Palm (uses one super bar)
[State -1, Saber]
type = ChangeState
value = ifelse((command="TwoPunches"||var(52)=3110)&&power>=2000,3110,3100)
;value = 3100
triggerall = (ifelse( (anim=[5,6]), (command="GenericSuper"), (command = "SaberSuper") ) && !var(55)) || var(52) = 3100
triggerall = power >= 1000
triggerall = !numhelper(3105)
trigger1 = var(9)
trigger2 = (stateno = 1050) || (stateno = 1060) || (stateno = 1070 && anim = 1051) || (stateno = 210 && anim = 219) || (stateno = 220) || (stateno = 410) || (stateno = 230 && anim = 230) || (stateno = 240 && anim = 240)
trigger2 = movecontact
trigger3 = stateno = 3002
trigger3 = anim = 3004
trigger3 = animelemtime(18) >= 0
trigger4 = stateno = 1101

;Triple Kung Fu Palm (uses one super bar)
[State -1, Ringer]
type = ChangeState
value = 3200
triggerall = (ifelse( (anim=[5,6]), (command="Houtenjin"), (command = "DeadRinger") ) && !var(55)) || var(52) = 3200
triggerall = power >= 1000
triggerall = !numhelper(3200)
triggerall = var(23) = 0
trigger1 = var(9)
trigger2 = (stateno = 1050) || (stateno = 1060) || (stateno = 1070 && anim = 1051) || (stateno = 210 && anim = 219) || (stateno = 220) || (stateno = 410) || (stateno = 230 && anim = 230) || (stateno = 240 && anim = 240)
trigger2 = movecontact
trigger3 = stateno = 3002
trigger3 = anim = 3004
trigger3 = animelemtime(18) >= 0
trigger4 = stateno = 1101

;Triple Kung Fu Palm (uses one super bar)
[State -1, HOUTENJIN]
type = ChangeState
value = 3400
triggerall = (ifelse( (anim=[5,6]), (command="DeadRinger"), (command = "Houtenjin") ) && !var(55)) || var(52) = 3400
triggerall = power >= 1000
trigger1 = var(9)
trigger2 = (stateno = 1050) || (stateno = 1060) || (stateno = 1070 && anim = 1051) || (stateno = 210 && anim = 219) || (stateno = 220) || (stateno = 410) || (stateno = 230 && anim = 230) || (stateno = 240 && anim = 240)
trigger2 = movecontact
trigger3 = stateno = 3002
trigger3 = anim = 3004
trigger3 = animelemtime(18) >= 0
trigger4 = stateno = 1101


;---------------------------------------------------------------------------
;Light Kung Fu Palm
[State -1, EX Genocide Plasma Cutter]
type = ChangeState
value = 1120
triggerall = (ifelse( (anim=[5,6]), (command="r_PlasmaKickEX"), (command = "PlasmaKickEX") ) && !var(55)) || var(52) = 1120
triggerall = stateno != 1101
triggerall = power >= 500
triggerall = !numhelper(1105)
trigger1 = var(9) ;Use combo condition (above)
trigger2 = statetype = A
trigger2 = ctrl
trigger3 = (stateno = [600,645]) || (stateno = 207)
trigger3 = movecontact

[State -1, Genocide Plasma Cutter]
type = ChangeState
value = 1100
triggerall = (ifelse( (anim=[5,6]), (command="r_PlasmaKick1"), (command = "PlasmaKick1") ) && !var(55)) || var(52) = 1100
triggerall = stateno != 1101
triggerall = !var(55) || (var(54) != 2 || p2statetype != L)
trigger1 = var(9) ;Use combo condition (above)
trigger2 = statetype = A
trigger2 = ctrl
trigger3 = (stateno = [600,645]) || (stateno = 207)
trigger3 = movecontact

[State -1, Genocide Plasma Cutter]
type = ChangeState
value = 1110
triggerall = (ifelse( (anim=[5,6]), (command="r_PlasmaKick2"), (command = "PlasmaKick2") ) && !var(55)) || var(52) = 1110
triggerall = stateno != 1101
trigger1 = var(9) ;Use combo condition (above)
trigger2 = statetype = A
trigger2 = ctrl
trigger3 = (stateno = [600,645]) || (stateno = 207)
trigger3 = movecontact

[State -1, EX SUCKer Punch]
type = ChangeState
value = 1070
triggerall = (ifelse( (anim=[5,6]), (command="GonnaRapeYouEX"), (command = "SuckerEX") ) && !var(55)) || var(52) = 1070
triggerall = power >= 500
trigger1 = var(9) ;Use combo condition (above)

[State -1, SUCKer Punch]
type = ChangeState
value = 1050
triggerall = (ifelse( (anim=[5,6]), (command="GonnaRapeYou1"), (command = "Sucker1") ) && !var(55)) || var(52) = 1050
trigger1 = var(9) ;Use combo condition (above)

[State -1, SUCKer Punch]
type = ChangeState
value = 1060
triggerall = (ifelse( (anim=[5,6]), (command="GonnaRapeYou2"), (command = "Sucker2") ) && !var(55)) || var(52) = 1060
trigger1 = var(9) ;Use combo condition (above)

[State -1, Grab Move]
type = ChangeState
value = 1170
triggerall = (ifelse( (anim=[5,6]), (command="SuckerEX"), (command = "GonnaRapeYouEX") ) && !var(55)) || var(52) = 1170
trigger1 = var(9) ;Use combo condition (above)
trigger1 = stateno != [1150,1199]
trigger1 = power >= 500

[State -1, Grab Move]
type = ChangeState
value = 1150
triggerall = (ifelse( (anim=[5,6]), (command="Sucker1"), (command = "GonnaRapeYou1") ) && !var(55)) || var(52) = 1150
trigger1 = var(9) ;Use combo condition (above)
trigger1 = stateno != [1150,1199]

[State -1, Grab Move]
type = ChangeState
value = 1160
triggerall = (ifelse( (anim=[5,6]), (command="Sucker2"), (command = "GonnaRapeYou2") ) && !var(55)) || var(52) = 1160
trigger1 = var(9) ;Use combo condition (above)
trigger1 = stateno != [1150,1199]

[State -1, EX Slip Move]
type = ChangeState
value = 1020
triggerall = (ifelse( (anim=[5,6]), (command="r_MatadorEX"), (command = "MatadorEX") ) && !var(55)) || var(52) = 1020
triggerall = power >= 500
trigger1 = var(9) ;Use combo condition (above)

[State -1, Slip Move]
type = ChangeState
value = 1000
triggerall = (ifelse( (anim=[5,6]), (command="r_Matador"), (command = "Matador") ) && !var(55)) || var(52) = 1000
trigger1 = var(9) ;Use combo condition (above)

;===========================================================================
;---------------------------------------------------------------------------
; Grab Move Followups
[State -1, KNEE YOU]
type = ChangeState
value = 1154
triggerall = (command = "a") || var(52) = 1154
trigger1 = stateno = 1151
trigger1 = animelemtime(2) >= 1
trigger1 = animelemtime(16) < 0

[State -1, LAUNCH YOU]
type = ChangeState
value = 1156
triggerall = (command = "x") || var(52) = 1156
trigger1 = stateno = 1151
trigger1 = animelemtime(2) >= 1
trigger1 = animelemtime(16) < 0

[State -1, TOSS YOU]
type = ChangeState
value = 1159
triggerall = (command = "y") || var(52) = 1159
trigger1 = stateno = 1151
trigger1 = animelemtime(2) >= 1
trigger1 = animelemtime(16) < 0

[State -1, DUNK YOU]
type = ChangeState
value = 1163
triggerall = (command = "b") || var(52) = 1163
trigger1 = stateno = 1151
trigger1 = animelemtime(2) >= 1
trigger1 = animelemtime(16) < 0

[State -1, INFINITE YOU]
type = ChangeState
value = 1171
triggerall = (command = "PutDown") || var(52) = 1171
;triggerall = power >= 500
triggerall = var(22) = 0
trigger1 = stateno = 1151
trigger1 = prevstateno = 1170
trigger1 = animelemtime(2) >= 1
trigger1 = animelemtime(16) < 0

[State -1, FATALITY YOU]
type = ChangeState
value = 1180
;triggerall = command = "PutDown"
;triggerall = power >= 500
;triggerall = var(22) = 0
triggerall = var(47)
triggerall = numtarget
triggerall = target,life<=50
triggerall = (target,selfanimexist(29993) ) || (target,selfanimexist(9108112) )
trigger1 = stateno = 1151
trigger1 = prevstateno != 1170 || time >= 60
trigger1 = animelem = 15

;---------------------------------------------------------------------------
[State -1, Alpha Counter]
type = ChangeState
value = 700
triggerall = (command = "GuardAttack") || var(52) = 700
triggerall = power >= 500
triggerall = statetype != A
triggerall = !var(55) || p2bodydist x <= 60
trigger1 = stateno = [120,169]
trigger1 = !var(55) || (stateno = [150,159])

;---------------------------------------------------------------------------
[State -1, SideStep]
type = ChangeState
value = 710
triggerall = (command = "Dodge" && !var(55)) || var(52) = [710,711]
triggerall = statetype != A
trigger1 = (ctrl) || (stateno = 100)
trigger2 = (stateno = [120,169]) || (stateno = 200 && movecontact) || (stateno = 201 && movecontact) || (stateno = 230 && anim = 235 && movecontact)
trigger2 = power >= 500
trigger2 = !var(55) || random < 150

;===========================================================================
;---------------------------------------------------------------------------
;Run Fwd
[State -1, Run Fwd]
type = ChangeState
value = 100
triggerall = stateno != 100
triggerall = (command = "FF") || var(52) = 100
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Run Back
[State -1, Run Back]
type = ChangeState
value = 105
triggerall = (command = "BB") || var(52) = 105
trigger1 = statetype = S
trigger1 = ctrl || stateno = 100

;---------------------------------------------------------------------------
;Kung Fu Throw
[State -1, Slip Throw]
type = ChangeState
value = 800
triggerall = (command = "b") || var(52) = 800
triggerall = statetype = S
triggerall = ctrl
triggerall = stateno != 100
triggerall = var(8) <= 0
trigger1 = command = "holdfwd" || command = "holdback"
trigger1 = p2bodydist X < 8
trigger1 = (p2statetype = S) || (p2statetype = C)
trigger1 = p2movetype != H

[State -1, Sniper Throw]
type = ChangeState
value = 830
triggerall = (command = "y") || var(52) = 830
triggerall = statetype = S
triggerall = ctrl
triggerall = stateno != 100
triggerall = var(8) <= 0
trigger1 = command = "holdfwd" || command = "holdback"
trigger1 = p2bodydist X < 8
trigger1 = (p2statetype = S) || (p2statetype = C)
trigger1 = p2movetype != H

[State -1, Air Throw]
type = ChangeState
value = 860
triggerall = (command = "y" || command = "b") || var(52) = 860
triggerall = statetype = A
triggerall = ctrl
trigger1 = command = "holdfwd" || command = "holdback"
trigger1 = p2bodydist X < 10
trigger1 = abs(p2bodydist y) < 35
trigger1 = (p2statetype = A)
trigger1 = p2movetype != H

;===========================================================================
;---------------------------------------------------------------------------
; Command Moves
[State -1, Stand Running Punch]
type = ChangeState
value = 220
triggerall = (command = "x" || command = "y") || (var(52) = [200,210])
trigger1 = anim = 100
trigger1 = animelemtime(3) >= 0
trigger1 = vel x >= 6
trigger1 = stateno = 100

[State -1, Stand Low Kick]
type = ChangeState
value = 237
triggerall = (command = "a"  && command = "holdfwd" && command != "holddown" && !var(55)) || var(52) = 237
trigger1 = statetype != A
trigger1 = (ctrl) || (stateno = 100)
trigger2 = (stateno = [200,202]) || (stateno = 210 && anim = 215) || (stateno = 230 && anim = 235) || (stateno = 240 && anim = 245) || stateno = 400 || stateno = 430 || stateno = 211 || stateno = 440
trigger2 = time > 8 || movecontact
trigger3 = (stateno = 1156 || stateno = 1159) && (animelemtime(9) >= 0)

[State -1, Stand Leap Attack]
type = ChangeState
value = 207
triggerall = (command = "x"  && command = "holdfwd" && command != "holddown" && !var(55)) || var(52) = 207
trigger1 = statetype != A
trigger1 = (ctrl) || (stateno = 100)
trigger2 = (stateno = [200,202]) || (stateno = 210 && anim = 215) || (stateno = 230 && anim = 235) || (stateno = 240 && anim = 245) || stateno = 400 || stateno = 430 || stateno = 211 || stateno = 440
trigger2 = time > 8 || movecontact
trigger3 = (stateno = 1156 || stateno = 1159) && (animelemtime(9) >= 0)


;===========================================================================
;---------------------------------------------------------------------------
; Standing Swipes
[State -1, Stand Swipe]
type = ChangeState
value = 200
triggerall = (command = "x" && command != "holddown") || var(52) = 200
trigger1 = statetype != A
trigger1 = (ctrl) || (stateno = 100)
trigger2 = (stateno = 1156 || stateno = 1159) && (animelemtime(9) >= 0)

[State -1, Stand Swipe 2]
type = ChangeState
value = 201
triggerall = (command = "x" && command != "holddown") || var(52) = 200
trigger1 = stateno = 200
trigger1 = time > 8 || movecontact

[State -1, Stand Swipe 3]
type = ChangeState
value = 202
triggerall = (command = "x") || var(52) = 200
;triggerall = command != "holddown"
trigger1 = stateno = 201 || stateno = 400 || stateno = 430 || stateno = 211
trigger1 = time > 8 || movecontact

; Standing Hard Punches
[State -1, Stand(alone) Hard Punch]
type = ChangeState
value = ifelse(stateno=100,213,210)
triggerall = (command = "y" && command != "holddown") || var(52) = 210
trigger1 = statetype != A
trigger1 = (ctrl) || (stateno = 100)
trigger2 = stateno = 201 || stateno = 400 || stateno = 430 || stateno = 211
trigger2 = time > 8 || movecontact
trigger3 = (stateno = 1156 || stateno = 1159) && (animelemtime(9) >= 0)

[State -1, Stand Hard Punch]
type = ChangeState
value = 211
triggerall = (command = "y") || var(52) = 210
;triggerall = command != "holddown"
trigger1 = stateno = 200
trigger1 = time > 8 || movecontact

[State -1, Stand Uppercut]
type = ChangeState
value = 213
triggerall = (command = "y") || var(52) = 210
;triggerall = command != "holddown"
trigger1 = stateno = 202 || (stateno = 210 && anim = 215)
trigger1 = time > 8 || movecontact

; Standing Kicks
[State -1, Stand Kick]
type = ChangeState
value = 230
triggerall = (command = "a" && command != "holddown") || var(52) = 230
trigger1 = statetype != A
trigger1 = (ctrl) || (stateno = 100)
trigger2 = stateno = 200 || stateno = 201 || stateno = 202 || stateno = 400 || (stateno = 210 && anim = 215)
trigger2 = time > 8 || movecontact
trigger3 = (stateno = 1156 || stateno = 1159) && (animelemtime(9) >= 0)

[State -1, Stand Heavy Kick]
type = ChangeState
value = 240
triggerall = (command = "b" && command != "holddown") || var(52) = 240
trigger1 = statetype != A
trigger1 = (ctrl) || (stateno = 100)
trigger2 = stateno = 200 || stateno = 201 || stateno = 202 || stateno = 400 || (stateno = 230 && anim = 235) || (stateno = 210 && anim = 215)
trigger2 = time > 8 || movecontact
trigger3 = (stateno = 1156 || stateno = 1159) && (animelemtime(9) >= 0)


;---------------------------------------------------------------------------
;Taunt
[State -1, Taunt]
type = ChangeState
value = 195
;value = 3010
triggerall = command = "start"
triggerall = stateno != 195
triggerall = !var(55) || p2bodydist x >= 60
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Crouching Attacks
[State -1, Crouching Swipe]
type = ChangeState
value = 400
triggerall = (command = "x" && command = "holddown") || var(52) = 400
trigger1 = statetype != A
trigger1 = (ctrl) || (stateno = 100)
trigger2 = (stateno = 1156 || stateno = 1159) && (animelemtime(9) >= 0)

[State -1, Crouching Uppercut]
type = ChangeState
value = 410
triggerall = (command = "y" && command = "holddown") || var(52) = 410
trigger1 = statetype != A
trigger1 = (ctrl) || (stateno = 100)
trigger2 = stateno = 400 || stateno = 430
trigger2 = time > 9 || movecontact
trigger3 = (stateno = 1156 || stateno = 1159) && (animelemtime(9) >= 0)

[State -1, Crouching Kick]
type = ChangeState
value = 430
triggerall = (command = "a" && command = "holddown") || var(52) = 430
trigger1 = statetype != A
trigger1 = (ctrl) || (stateno = 100)
trigger2 = stateno = 430
trigger2 = time > 8 || movecontact
trigger3 = (stateno = 1156 || stateno = 1159) && (animelemtime(9) >= 0)

[State -1, Crouching Sweep]
type = ChangeState
value = 440
triggerall = (command = "b" && command = "holddown") || var(52) = 440
trigger1 = statetype != A
trigger1 = (ctrl) || (stateno = 100)
trigger2 = stateno = 400 || stateno = 430 || stateno = 200
trigger2 = time > 8 || movecontact
trigger3 = (stateno = 1156 || stateno = 1159) && (animelemtime(9) >= 0)

;---------------------------------------------------------------------------
;Jump Attacks
[State -1, Jump Punch]
type = ChangeState
value = 600
triggerall = (command = "x" && !var(55)) || var(52) = 600
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 630
trigger2 = statetime >= 9 || movecontact
trigger2 = sysvar(3) >= 3

[State -1, Jump Elbow]
type = ChangeState
value = 610
triggerall = (command = "y" && !var(55)) || var(52) = 610
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 630 || stateno = 600 || stateno = 640 || stateno = 645 || stateno = 647
trigger2 = statetime >= 9 || movecontact
trigger2 = sysvar(3) >= 3

[State -1, Jump Knee]
type = ChangeState
value = 630
triggerall = (command = "a" && !var(55)) || var(52) = 630
trigger1 = statetype = A
trigger1 = ctrl

[State -1, Jump Up-Kick]
type = ChangeState
value = 645
triggerall = ((command = "holdup" && command = "b") && !var(55)) || var(52) = 645
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 630 || stateno = 600 || stateno = 640
trigger2 = statetime >= 9 || movecontact
trigger2 = sysvar(3) >= 3

[State -1, Jump Crossup-Kick]
type = ChangeState
value = 647
triggerall = ((command = "holdback" && command = "b") && !var(55)) || var(52) = 647
triggerall = !var(55) || p2dist x < -5
trigger1 = statetype = A
trigger1 = ctrl

[State -1, Jump Kick]
type = ChangeState
value = 640
triggerall = (command = "b" && !var(55)) || var(52) = 640
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 630 || stateno = 600 || stateno = 647
trigger2 = statetime >= 9 || movecontact
trigger2 = sysvar(3) >= 3

; MVC
[State -1, Jump-In]
type = ChangeState
value = 40
triggerall = (command = "holdup") || (var(52) = [40,49])
trigger1 = (stateno = 240 && anim = 245) || (stateno = 213)
trigger1 = time > 12 || movecontact
trigger2 = (stateno = 1156)
trigger2 = animelemtime(9) >= 0
trigger3 = stateno = 100
trigger4 = stateno = 3400
trigger4 = movehit
trigger5 = var(55)
trigger5 = statetype != A
trigger5 = ctrl

;[State DEBUG]
;type = ChangeState
;triggerall = stateno != [3000,3999]
;trigger1 = numtarget
;trigger1 = target,stateno = 226
;trigger1 = target,time = 1
;trigger1 = target,vel x + target,BackEdgeBodyDist <= 40
;trigger1 = target,movetype = H
;value = 3000
;ignorehitpause = 1

